@@ -1,14 +1,13 @@
 from appium.webdriver.appium_service import AppiumService
 appium_service = AppiumService()
 from appiumbase import config as ab_config
+import requests
 
 def start_appium_service():
-    if (appium_service.is_running() and appium_service.is_listening()):
-        pass
-        #appium service is already running and listening
-    else:
+    try:
+        res = requests.get("http://0.0.0.0:4723/wd/hub/sessions")
+    except requests.exceptions.ConnectionError as e:
         appium_service.start()
-    ab_config.appium_server_running = appium_service.is_listening()
 
 def stop_appium_service():
-    appium_service.stop()
+    appium_service.stop()
\ No newline at end of file
